package cn.com.qmth.examcloud.service.core.api;

import cn.com.qmth.examcloud.common.uac.entity.AccessUser;
import cn.com.qmth.examcloud.service.core.entity.User;
import cn.com.qmth.examcloud.service.core.enums.UserType;
import cn.com.qmth.examcloud.service.core.repo.UserRepo;
import cn.com.qmth.examcloud.service.core.service.UserService;
import io.swagger.annotations.ApiOperation;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;

import java.util.List;

import javax.servlet.http.HttpServletRequest;

/**
 * 用户服务API
 * Created by songyue on 17/1/13.
 */
@RestController
@RequestMapping("${app.api.root}/user")
public class UserApi {

    @Autowired
    UserService userService;

    @Autowired
    UserRepo userRepo;


//    @ApiOperation(value="查询所有用户")
//    @GetMapping
//    public ResponseEntity getAllUser(){
//        return new ResponseEntity(userRepo.findAll(), HttpStatus.OK);
//    }

    @ApiOperation(value="按id查询用户",notes="id查询")
    @GetMapping("/{id}")
    public ResponseEntity getUserById(@PathVariable long id){
        return new ResponseEntity(userRepo.findOne(id), HttpStatus.OK);
    }

    @ApiOperation(value="按orgId查询用户",notes="机构id查询机构用户")
    @GetMapping("/org/{orgId}")
    public ResponseEntity getUserByOrgId(@PathVariable long orgId){
        List<User> userList = userRepo.findByOrgIdAndType(orgId, UserType.NOT_STUDENT.name());
        return new ResponseEntity(userList, HttpStatus.OK);
    }

    @ApiOperation(value="按rootOrgId查询用户",notes="根机构id查询机构用户")
    @GetMapping("/rootOrg/{rootOrgId}")
    public ResponseEntity getUserByRootOrgId(@PathVariable long rootOrgId){
        List<User> userList = userRepo.findByRootOrgIdAndType(rootOrgId, UserType.NOT_STUDENT.name());
        return new ResponseEntity(userList, HttpStatus.OK);
    }

    @ApiOperation(value="新增用户",notes="新增")
    @PostMapping
    public ResponseEntity addUser(@RequestBody User user){
        return new ResponseEntity(userRepo.save(user), HttpStatus.CREATED);
    }

    @ApiOperation(value="更新用户",notes="更新")
    @PutMapping
    public ResponseEntity updateUser(@RequestBody User user){
        return new ResponseEntity(userRepo.save(user), HttpStatus.OK);
    }

    @ApiOperation(value="重置用户密码",notes="重置密码")
    @PutMapping("/resetPass/{id}")
    public ResponseEntity resetPass(@PathVariable long id){
        userService.initPassword(id);
        return new ResponseEntity(HttpStatus.OK);
    }

    @ApiOperation(value="修改用户密码",notes="修改密码")
    @PutMapping("/password")
    public ResponseEntity updatePass(@RequestParam long userId,@RequestParam String password){
        userRepo.updatePasswordById(userId,password);
        return new ResponseEntity(HttpStatus.OK);
    }

    @ApiOperation(value="按id删除用户",notes="删除")
    @DeleteMapping("/{id}")
    public ResponseEntity deleteUser(@PathVariable long id){
        userRepo.delete(id);
        return new ResponseEntity(HttpStatus.OK);
    }

    @ApiOperation(value="一般登录",notes="登录")
    @PostMapping("/login")
    public ResponseEntity login(@RequestParam String loginName,
                                @RequestParam String password){
        return userService.login(loginName,password);
    }

    @ApiOperation(value="二级登录",notes="二级登录")
    @PostMapping("/login/{orgId}")
    public ResponseEntity login(@PathVariable long orgId,
                                @RequestParam String loginName,
                                @RequestParam String password){
        return userService.login(orgId,loginName,password);
    }
    
    @ApiOperation(value="登出",notes="登出")
    @PostMapping("/logout")
    public ResponseEntity logout(HttpServletRequest request){
    	AccessUser accessUser = (AccessUser) request.getAttribute("accessUser");
    	userService.logout(accessUser);
        return new ResponseEntity(HttpStatus.OK);
    }
}
